#  Class: tomcat
#
#  Install and configure tomcat with java  
#
#  Parameters
#
#  [*$source_path*]
#  The is the directory from  where the tomcat module will get its setup files and configurations
# 
#  [*$java_version*]
#  The parameter checks version of java i.e java 1.7  or java 1.8 
# 
#  [*$java_dir*]
#  The is the base directory on which java is deployed.
# 
#  [*$platform*]
#  This parameter takes input from the user to check machine platform i.e x86 bit or x64 bit.
# 
#  [*$env_path*]
#  The is the parameter which sets java path.
# 
#  [*$tomcat_version*]
#  Specify tomcat version which you want to install  
# 
#  [*$tomcat_path*]
#  Specify tomcat path 
# 
#  [*$javaDownloadURI*]
#  Specify java download url  
#  
#  Authors
#
#  Boxupp Team <http://boxupp.com/>
#
#  Copyright
#  Copyright © 2014-2015 Paxcel Technologies (p) Ltd
#  site : http://paxcel.net/   http://boxupp.com/

 class tomcat ( 
    #Define java_version here 
    $java_version   = '7u65',
    #Define OS platform here
    $platform       = 'x64',
    # Define  tomcat version.
    $tomcat_version = 'tomcat-7', ) {

  #Define java_dir here 
  $java_dir       = '/usr/local/java'
  # Define your environment variable diectory path here.
  $env_path       = '/root/.bash_profile'
  # Define  tomcat diectory path here.
  $tomcat_dir    = '/usr/local/tomcat'
  $exec_path      = '/bin:/sbin:/usr/bin:/usr/sbin:/usr/local/bin:/usr/local/sbin'    
  $ensure         = 'present'
  $install_dir    = '/usr/local'
  $source_dir     = '/usr/src'    
    
  case $platform {
    'x64': { $plat_filename = 'x64'  }
    'x86': { $plat_filename = 'i586' }
    default: { fail("Unsupported platform: ${platform}.  Implement me?") }
  }
  
#  case $java_version {
#    '8u11':  { $java_home = "${java_dir}/jdk1.8.0_11"  }
#    '7u65':  { $java_home = "${java_dir}/jdk1.7.0_65"  }
#    default: { fail("Unsupported java_version: ${java_version}.  Implement me?")   }
#  }

  notify {'Install ${java_file_name}':}
  $java_file_name = "jdk-${java_version}-linux-${plat_filename}.tar.gz"
  
  case $tomcat_version { 
    'tomcat-7':  { notify {'Install apache-tomcat-7.0.54.tar.gz':} }
    'tomcat-8':  { notify {'Install apache-tomcat-8.0.9.tar.gz':} }
    default:     { notify {'Install apache-tomcat-7.0.53.tar.gz':} }
  }

  case $tomcat_version {
    'tomcat-7':  { $tomcat_file_name = 'apache-tomcat-7.0.54.tar.gz' }
    'tomcat-8':  { $tomcat_file_name = 'apache-tomcat-8.0.9.tar.gz'  }
    default:     { $tomcat_file_name = 'apache-tomcat-7.0.53.tar.gz' }
  }

  notify {'Copy Tomcat to hosts':}
  file { 'copy_tomcat':
    ensure => $ensure,
    force   => true,
    path   => "${source_dir}/${tomcat_file_name}",
    source => "puppet:///modules/tomcat/${tomcat_file_name}",
  }

  notify {'Copy Java to hosts':}
  file { 'copy_java':
     ensure  => $ensure,
     path    => "${source_dir}/${java_file_name}",
     force   => true,
     source  => "puppet:///modules/tomcat/${plat_filename}/${java_file_name}",
  }

  notify {'Extract Java':}
  notify {"Comand tar zxf ${source_dir}/${java_file_name} to Extract Java":}
  if ( $java_version in [ '7u65', '8u11' ] ) {
    exec { 'extract_java':
      cwd     => $install_dir,
      command => "tar zxf ${source_dir}/${java_file_name}",
      creates => $java_dir,
      path    => $exec_path,
      require => File['copy_java']
    }
    
  }
  notify {'Extract JDK Complete':}

  notify {'Extract Tomcat':}
  exec { 'extract_tomcat':
    cwd     => $install_dir,
    command => "tar zxf ${source_dir}/${tomcat_file_name}",
    creates => $tomcat_dir,
    path    => $exec_path,
    require => File['copy_tomcat']
  }
  notify {'Extract Tomcat Complete':}
  
  
  if ( $java_version in [ '7u65', '8u11' ] ) {
    exec { "set_java_home":
      command => "echo 'export JAVA_HOME=${::java_home}'>> ${env_path}",
      unless  => "grep 'JAVA_HOME=${::java_home}' ${env_path}",
      require => Exec["extract_java"],
    }
  }
  
  exec { "java_path":
    command => "echo 'export PATH=\$JAVA_HOME/bin:\$PATH' >> ${env_path}",
    unless  => "grep 'export PATH=\$JAVA_HOME/bin:\$PATH' ${env_path}",
    require => Exec["set_java_home"],
  }
      
  exec { "set_env":
    command => "bash -c 'source ${env_path}'",
    require => Exec["java_path"];
  }
  
  service { "iptables":
    enable => true,
    ensure => stopped,
    require => Exec["extract_tomcat"],
  }

  case $tomcat_version {
    'tomcat-7':  { $tomcat_service_name = 'tomcat7' }
    'tomcat-8':  { $tomcat_service_name = 'tomcat8'  }
    default:     { $tomcat_service_name = 'tomcat7' }
  }

  file { 'tomcat_service_path':
      path => "/etc/init.d/${tomcat_service_name}",
      mode => "0755",
      owner => "root",
      group => "root",
      source => "puppet:///modules/tomcat/tomcat.sh",
      require => Exec["extract_tomcat"],      
  }    
    
  service { 'tomcat_service':
      name   => "${tomcat_service_name}",
      enable => true,
      require => File["tomcat_service_path"],      
  }

} 
